#    This file is part of unforward
# 
#    Unforward is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#    
#    Unforward is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#    
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
#

from unforward.emailclients.emailclient import EmailClient
from unforward.errors import ExtractionError
from bs4 import BeautifulSoup
from pprint import pprint
import datetime


class GmailClient(EmailClient):
    """ Extracts originals from gmail clients."""
    
    client_type = 'gmail'
    implemented = True
    
    def extract(self, email):
        pass

    def check_match(self, string):
        """ This method should look at the given string, and as quickly as possible determine if it contains a
            forward from this email client. """
        string = str(string)
        return string.find('gmail_sendername') != -1 and string.find('---------- Forwarded message ----------') != -1
    
    def extract_from_html(self, string):
        try:
            parsed = BeautifulSoup(string, "lxml")
            gmail_quote = parsed.find("div", class_ = "gmail_quote")
            if gmail_quote is not None:
                if gmail_quote.div is None:
                    body = ''.join(str(tag).strip() for tag in gmail_quote.contents[18:])
                    date = datetime.datetime.strptime(gmail_quote.contents[7].strip(), "Date: %a, %b %d, %Y at %I:%M %p")
                    sender = gmail_quote.span.a.get_text()
                elif len(gmail_quote) < 10:
                    body = ''.join(str(tag).strip() for tag in gmail_quote.contents[1:])
                    date = datetime.datetime.strptime(gmail_quote.contents[0].contents[7].strip(), "Date: %a, %b %d, %Y at %I:%M %p")
                    sender = gmail_quote.span.a.get_text()                
                else:
                    body = ''.join(str(tag).strip() for tag in gmail_quote.div.contents)
                    date = datetime.datetime.strptime(gmail_quote.contents[7].strip(), "Date: %a, %b %d, %Y at %I:%M %p")
                    sender = gmail_quote.span.a.get_text()
                return {"body" : body, "sender" : sender, "date" : date}
            else:
                raise ExtractionError("Parsing of forward failed. No div with class gmail_quote was found.")
               
        except Exception as e:
            raise ExtractionError("Given email did not parse successfully: " + str(e))

        

