#    This file is part of unforward
# 
#    Unforward is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#    
#    Unforward is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#    
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
#

from unforward.emailclients.emailclient import EmailClient
from unforward.errors import ExtractionError
from bs4 import BeautifulSoup
from pprint import pprint
import datetime
import dateutil.parser
import dateutil.tz

class OutlookExpressClient(EmailClient):
    """ Extracts originals from OutlookExpress clients"""
    
    client_type = 'outlook'
    implemented = True
    
    def extract(email):
        pass
    
    def check_match(self, string):
        """ This method should look at the given string, and as quickly as possible determine if it contains a
            forward from this email client. """
        return string.find('Begin forwarded message:') != -1 and string.find('<blockquote type="cite">') != -1
    
    def extract_from_html(self, string):
        try:
            parsed = BeautifulSoup(string)
            blockquotes = parsed.html.body.find_all('blockquote')
            if len(blockquotes) > 1:
                sender = blockquotes[0].a.get_text()
                body = ''.join(str(tag).strip() for tag in blockquotes[1].contents)
                datestring = str(blockquotes[0].find_all('b')[1].next_sibling).strip().replace("\u00A0", " ")
                date = dateutil.parser.parse(datestring)
            else:
                sender = blockquotes[0].a.get_text()
                bodydivs = blockquotes[0].find_all('div')
                body = ''.join(str(tag).strip() for tag in bodydivs[-1].contents)
                datestring = str(bodydivs[2].find_all('span')[1].contents[0]).strip().replace("\u00A0", " ")
                date = dateutil.parser.parse(datestring)
                        
                        
            return {"body" : body, "sender" : sender, "date" : date}
        except Exception as e:
            raise ExtractionError("Given email did not parse as an outlook forward successfully: " + str(e))
        
    

